==> edge-login-ui-rn-2.12.0.tgz: package/lib/components/abSpecific/LogoImageHeader.js <==
import * as React from 'react';
import { Image, TouchableWithoutFeedback, View } from 'react-native';
import * as Assets from '../../assets/';
import s from '../../common/locales/strings';
import { scale } from '../../util/scaling';
export class LogoImageHeader extends React.Component {
    constructor(props) {
        super(props);
        this.handlePress = () => {
            const callback = this.props.branding.primaryLogoCallback;
            if (callback != null) {
                const taps = this.state.taps + 1;
                this.setState({ taps });
                if (taps > 4) {
                    callback();
                    this.setState({ taps: 0 });
                }
                if (taps === 1) {
                    setTimeout(() => this.setState({ taps: 0 }), 2000);
                }
            }
        };
        this.state = {
            taps: 0
        };
    }
    render() {
        const src = this.props.branding.primaryLogo || Assets.LOGO_BIG;
        return (React.createElement(TouchableWithoutFeedback, { onPress: this.handlePress },
            React.createElement(View, { style: styles.container },
                React.createElement(Image, { accessibilityHint: s.strings.app_logo_hint, source: src, style: styles.image, resizeMode: "contain" }))));
    }
}
const styles = {
    container: {
        position: 'relative',
        width: '100%',
        paddingBottom: scale(24),
        justifyContent: 'space-around',
        alignItems: 'center'
    },
    image: {
        position: 'relative',
        height: scale(44),
        overflow: 'visible',
        resizeMode: 'contain'
    }
};

==> edge-login-ui-rn-2.16.0.tgz: package/lib/components/abSpecific/LogoImageHeader.js <==
import * as React from 'react';
import { Image, TouchableWithoutFeedback, View } from 'react-native';
import * as Assets from '../../assets/';
import { lstrings } from '../../common/locales/strings';
import { scale } from '../../util/scaling';
export class LogoImageHeader extends React.Component {
    constructor(props) {
        super(props);
        this.handlePress = () => {
            const callback = this.props.branding.primaryLogoCallback;
            if (callback != null) {
                const taps = this.state.taps + 1;
                this.setState({ taps });
                if (taps > 4) {
                    callback();
                    this.setState({ taps: 0 });
                }
                if (taps === 1) {
                    setTimeout(() => this.setState({ taps: 0 }), 2000);
                }
            }
        };
        this.state = {
            taps: 0
        };
    }
    render() {
        const src = this.props.branding.primaryLogo || Assets.LOGO_BIG;
        return (React.createElement(TouchableWithoutFeedback, { onPress: this.handlePress },
            React.createElement(View, { style: styles.container },
                React.createElement(Image, { accessibilityHint: lstrings.app_logo_hint, source: src, style: styles.image, resizeMode: "contain" }))));
    }
}
const styles = {
    container: {
        position: 'relative',
        width: '100%',
        paddingBottom: scale(24),
        justifyContent: 'space-around',
        alignItems: 'center'
    },
    image: {
        position: 'relative',
        height: scale(44),
        overflow: 'visible',
        resizeMode: 'contain'
    }
};
